package com.qmth.distributed.print.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.distributed.print.business.bean.dto.TCStatisticsDto;
import com.qmth.distributed.print.business.entity.TCStatistics;
import com.qmth.distributed.print.business.enums.StatisticsStatusEnum;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.util.Result;

import java.sql.ResultSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * <p>
 * 命题统计表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2021-09-09
 */
public interface TCStatisticsService extends IService<TCStatistics> {

    /**
     * 查找印刷计划信息
     *
     * @param iPage
     * @param collegeId
     * @param teachingRoomId
     * @param status
     * @param courseName
     * @param teacherName
     * @param schoolId
     * @param userId
     * @return
     */
    public IPage<TCStatisticsDto> list(IPage<Map> iPage,
                                       Long collegeId,
                                       Long teachingRoomId,
                                       StatisticsStatusEnum status,
                                       String courseName,
                                       String teacherName,
                                       Long schoolId,
                                       Long userId);

    /**
     * 根据batchNo统计信息
     *
     * @param schoolId
     * @param batchNo
     * @param orgIds
     * @return
     */
    public List<TCStatisticsDto> findByBatchNoCount(Long schoolId, String batchNo, Set<Long> orgIds);

    /**
     * 根据batchNo统计信息
     *
     * @param schoolId
     * @param batchNo
     * @param orgIds
     * @return
     */
    public List<TCStatisticsDto> findByBatchNoCountJoin(Long schoolId, String batchNo, Set<Long> orgIds);

    /**
     * 导入关联数据
     *
     * @param sysUser
     * @param batchNo
     */
    public void importJoinData(SysUser sysUser, String batchNo);

    /**
     * 删除导入数据
     *
     * @param courseSet
     * @param setCollections
     */
    public void removeImportData(Set<String> courseSet, Set<Long>... setCollections);

    /**
     * 刷新关联数据
     *
     * @param sysUser
     * @param batchNoSet
     */
    public void freshenJoinData(SysUser sysUser, Set<String> batchNoSet);

    /**
     * 删除旧的关联数据
     *
     * @param batchNoSet
     */
    public void removeOldJoinData(Set<String> batchNoSet);

    /**
     * 刷新数据
     *
     * @return
     */
    public Result freshenData();

    /**
     * 删除数据
     *
     * @param ids
     * @return
     */
    public Result deleteData(List<Long> ids);
}
